@@ -48,7 +48,7 @@ from ctypes import c_char_p, c_int, c_void_p, create_string_buffer, \
                     POINTER, byref, CDLL, cdll, util, cast
 c_int_p = POINTER(c_int)
 
-__version__ = '5.5.5'
+__version__ = '5.5.6'
 
 __all__ = ['get_version', 'lut_load', 'lut_is_valid', 'cleanup',
             'check_iban', 'create_iban', 'get_bic', 'get_name',
@@ -98,8 +98,12 @@ def scl_get_routing(bic):
         raise ValueError('invalid bic "%s"' % bic)
     bic = bic.ljust(11, 'X')
     cur = dbscl.cursor()
-    cur.execute("SELECT sct, sdd, cor1, b2b FROM scl WHERE bic = ? OR bic = ?;", (bic, bic[:8]))
+    query = "SELECT sct, sdd, cor1, b2b FROM scl WHERE bic = ?;"
+    cur.execute(query, (bic,))
     result = cur.fetchone()
+    if not result:
+        cur.execute(query, (bic[:8],))
+        result = cur.fetchone()
     cur.close()
     if not result:
         raise ValueError('unknown bic "%s"' % bic)
@@ -115,8 +119,12 @@ def scl_get_bankname(bic):
         raise ValueError('invalid bic "%s"' % bic)
     bic = bic.ljust(11, 'X')
     cur = dbscl.cursor()
-    cur.execute("SELECT name FROM scl WHERE bic = ? OR bic = ?;", (bic, bic[:8]))
+    query = "SELECT name FROM scl WHERE bic = ?;"
+    cur.execute(query, (bic,))
     result = cur.fetchone()
+    if not result:
+        cur.execute(query, (bic[:8],))
+        result = cur.fetchone()
     cur.close()
     if not result:
         raise ValueError('unknown bic "%s"' % bic)
